@@ -2,6 +2,8 @@
 from iqsopenapi.environment import Environment
 from iqsopenapi.models import *
 from iqsopenapi.core.Scheduler import *
+from collections import defaultdict
+from copy import copy
 
 class StrategyContext(object):
     """
@@ -123,52 +125,101 @@ class StrategyContext(object):
         self.__rebuild_data(data)
         return data
 
-    def insert_smart_order(self, symbol, quantity, price=None):
+    def insert_smart_order(self, symbol, quantity, price=None, today_first=True):
         """智能报单
+        symbol—合约代码, str
+        quantity—委托手数，正值表示买入，负值表示卖出, int
         当前多仓，正数：开多仓
         当前多仓，负数：平多仓，超过头寸数量反方向开空仓
         当前空仓，正数：平空仓，超过头寸数量反方向开多仓
         当前空仓，负数：开空仓
+
+        当前存在双向单，正数：平空仓，超过空头头寸数量开多仓
+        当前存在双向单，负数：平多仓，超过多头头寸数量开空仓
+
+        price—委托价格，None表示市价单，否则为限价单, float
+        today_first—平仓优先级，默认优先平今仓，超出部分平老仓
         """
         if quantity == 0:
-            return None
-        all_pos = self.get_positions()
-        if not all_pos:
-             return None
-        posList = []
-        for x in all_pos:
-            if x.symbol == symbol:
-                posList.append(x)
-        if posList is None or len(posList) <= 0:
-            return None
-        if len(posList) >= 2:
-            raise Exception('smart order only support one way position!')
-        pos = posList[0]
-        if pos.side == PosSide.Net:
-            raise Exception('smart order only support long or short position!')
+            raise Exception('smart order quantity must not be less than 0!')
         order_type = OrderType.LMT
         if price is None:
             price = 0.0
-            order_type = OrderType.MKT
+            order_type = OrderType.MKT  
+        pos = self.__get_smart_order_pos(symbol,quantity)
+        if pos is None:
+            if quantity > 0:
+                return self.insert_order(symbol,OrderSide.Buy,order_type,Offset.Open,price,quantity)
+            else:
+                return self.insert_order(symbol,OrderSide.Sell,order_type,Offset.Open,price,-quantity)
+        if pos.side == PosSide.Net:
+            raise Exception('smart order only support long or short position!')
         if pos.side == PosSide.Long and quantity > 0:
             return self.insert_order(symbol,OrderSide.Buy,order_type,Offset.Open,price,quantity)
         elif pos.side == PosSide.Long and quantity < 0:
-            if pos.quantity >= -quantity:
-                return self.insert_order(symbol,OrderSide.Sell,order_type,Offset.Close,price,-quantity)
+            closeQty = min(pos.quantity,-quantity)
+            order = None
+            if today_first:
+                if pos.today_qty > 0:
+                    order = self.insert_order(symbol,OrderSide.Sell,order_type,Offset.CloseToday,price,min(closeQty,pos.today_qty))
+                closeYesQty = closeQty - min(closeQty,pos.today_qty)
+                if closeYesQty > 0:
+                    order = self.insert_order(symbol,OrderSide.Sell,order_type,Offset.CloseYesterday,price,closeYesQty)
             else:
-                self.insert_order(symbol,OrderSide.Sell,order_type,Offset.Close,price,pos.quantity)
-                return self.insert_order(symbol,OrderSide.Sell,order_type,Offset.Open,price,pos.quantity - quantity)
+                yesQty = pos.quantity - pos.today_qty
+                if yesQty > 0:
+                    order = self.insert_order(symbol,OrderSide.Sell,order_type,Offset.CloseYesterday,price,min(closeQty,yesQty))
+                closeTodayQty = closeQty - min(closeQty,yesQty)
+                if closeTodayQty > 0:
+                    order = self.insert_order(symbol,OrderSide.Sell,order_type,Offset.CloseToday,price,closeTodayQty)
+            if -quantity - closeQty > 0:
+                return self.insert_order(symbol,OrderSide.Sell,order_type,Offset.Open,price,-quantity - closeQty)
+            else:
+                return order
         elif pos.side == PosSide.Short and quantity > 0:
-            if pos.quantity >= quantity:
-                return self.insert_order(symbol,OrderSide.Buy,order_type,Offset.Close,price,quantity)
+            closeQty = min(pos.quantity,quantity)
+            order = None
+            if today_first:
+                if pos.today_qty > 0:
+                    order = self.insert_order(symbol,OrderSide.Buy,order_type,Offset.CloseToday,price,min(closeQty,pos.today_qty))
+                closeYesQty = closeQty - min(closeQty,pos.today_qty)
+                if closeYesQty > 0:
+                    order = self.insert_order(symbol,OrderSide.Buy,order_type,Offset.CloseYesterday,price,closeYesQty)
             else:
-                self.insert_order(symbol,OrderSide.Buy,order_type,Offset.Close,price,pos.quantity)
-                return self.insert_order(symbol,OrderSide.Buy,order_type,Offset.Open,price,quantity - pos.quantity)
+                yesQty = pos.quantity - pos.today_qty
+                if yesQty > 0:
+                    order = self.insert_order(symbol,OrderSide.Buy,order_type,Offset.CloseYesterday,price,min(closeQty,yesQty))
+                closeTodayQty = closeQty - min(closeQty,yesQty)
+                if closeTodayQty > 0:
+                    order = self.insert_order(symbol,OrderSide.Buy,order_type,Offset.CloseToday,price,closeTodayQty)
+            if quantity - closeQty > 0:
+                return self.insert_order(symbol,OrderSide.Buy,order_type,Offset.Open,price,quantity - closeQty)
+            else:
+                return order
         elif pos.side == PosSide.Short and quantity < 0:
             return self.insert_order(symbol,OrderSide.Sell,order_type,Offset.Open,price,-quantity)
 
         raise Exception('smart order error!')
 
+    def __get_smart_order_pos(self,symbol, quantity):
+        '''获取智能单持仓'''
+        all_pos = self.get_positions()
+        if all_pos is None or symbol not in all_pos:
+             return None
+        if len(all_pos[symbol]) >= 2:
+            if quantity > 0:
+                if PosSide.Short in all_pos[symbol]:
+                    return all_pos[symbol][PosSide.Short]
+                raise Exception('smart order not exist short position!')
+            elif quantity < 0:
+                if PosSide.Long in all_pos[symbol]:
+                    return all_pos[symbol][PosSide.Long]
+                raise Exception('smart order not exist long position!')
+            else:
+                raise Exception('smart order quantity must not be less than 0!')
+        else:
+            return list(all_pos[symbol].values())[0]
+
     def cancel_order(self, order):
         """撤单"""
         data = Environment.get_instance().trade_api.CancelOrder(order)
@@ -209,19 +260,26 @@ class StrategyContext(object):
         """获取持仓"""
         data = Environment.get_instance().trade_api.GetPositions()
         if not data:
-            return data
+            return None
         self.__rebuild_data(*data)
-        return data
+        val = defaultdict(dict)
+        for x in data:
+            val[x.symbol][x.side] = x
+        return dict(val)
 
     def get_position(self, symbol):
         """获取持仓"""
         all_pos = self.get_positions()
-        if not all_pos:
-            return all_pos
-        for x in all_pos:
-            if x.symbol == symbol:
-                return x;
-        return None
+        if all_pos is None or symbol not in all_pos:
+             return {PosSide.Long:None,PosSide.Short:None}
+        val = copy(all_pos[symbol])
+        if PosSide.Long not in val:
+            val[PosSide.Long] = None
+            return val
+        if PosSide.Short not in val:
+            val[PosSide.Short] = None
+            return val
+        return val
 
     def get_account(self):
         """获取订阅列表"""
