@@ -12,7 +12,7 @@ def compile_strategy(source_code, strategy, scope):
         six.exec_(code, scope)
         return scope
     except Exception as e:
-        logger.error('compile strategy exception',e)
+        logger.exception(e)
 
 class FileStrategyLoader(IStrategyLoader):
     def __init__(self, strategy_file_path):
