@@ -48,7 +48,7 @@ class MarketApi(IMarketApi):
                 subRet = self.Subscribe(*self.__subscribes)
                 logger.debug("连接成功，订阅完成：{0}".format(subRet))
         except Exception as e:
-            logger.error('subscribe market exception',e)
+            logger.exception(e)
 
     def __OnRecv(self,msg):
         '''收到行情消息'''
@@ -93,8 +93,9 @@ class MarketApi(IMarketApi):
         req.Subscribes = subInfos
         message = json.dumps(req.__dict__,ensure_ascii=False)
         if not self.__Send(req.ReqID,message):
-            logger.error("send fail:{0}".format(message))
+            logger.error("Subscribe market send fail:{0}".format(message))
             return False
+        logger.info("Subscribe market succeed:{0}".format(message))
         for x in subInfos:
             if x not in self.__subscribes:
                 self.__subscribes.append(x)
@@ -132,8 +133,9 @@ class MarketApi(IMarketApi):
         req.Unsubscribes = subInfos
         message = json.dumps(req.__dict__,ensure_ascii=False)
         if not self.__Send(req.ReqID,message):
-            logger.error("send fail:{0}".format(message))
+            logger.error("Unsubscribe market send fail:{0}".format(message))
             return False
+        logger.info("Unsubscribe market succeed:{0}".format(message))
         for x in subInfos:
             if x in self.__subscribes:
                 self.__subscribes.remove(x)
