@@ -1,9 +1,10 @@
 # -*- coding: utf-8 -*-
 
-from iqsopenapi.models.AssetInfo import *
+from iqsopenapi.models.Account import *
 from iqsopenapi.models.BarData import *
 from iqsopenapi.models.Contract import *
 from iqsopenapi.models.Order import *
 from iqsopenapi.models.Position import *
 from iqsopenapi.models.TickData import *
 from iqsopenapi.models.ResultInfo import *
+from iqsopenapi.models.Trade import *
