@@ -7,9 +7,16 @@ from iqsopenapi.trade.realtrade.TradeEnums import TradeCounterType
 from iqsopenapi.trade.realtrade.Models import kv
 
 class SupervisionHelper:
-    def __init__(self, dir):
-        self.__baseDirectory = dir
-        os.chdir(dir)
+    def __init__(self):
+
+        if self.__isLinux():
+            self.__libpath = os.path.join(os.path.dirname(__file__), 'linux')
+        else:
+            if self.__isX64():
+                self.__libpath = os.path.join(os.path.dirname(__file__), 'win','x64')
+            else:
+                self.__libpath = os.path.join(os.path.dirname(__file__), 'win','x86')
+        os.chdir(self.__libpath)
 
     def string_buffer2string(self, buffer, length, code='ascii'):
         return buffer.value[:length].decode(code).strip()
@@ -28,11 +35,20 @@ class SupervisionHelper:
         return result, info, crypt
         
     def ctp(self):
-        ctp = cdll.LoadLibrary('WinDataCollect.dll')
         length = 1024
         array = (c_byte * length)()
         len = (c_int*1)()
-        result = ctp['?CTP_GetSystemInfo@@YAHPADAAH@Z'](array, len)
+        if self.__isLinux():
+            func_name = '_Z21CTP_GetRealSystemInfoPcRi'
+            absolute_dllfile_path = os.path.join(self.__libpath, 'LinuxDataCollect.so')
+            ctp = CDLL(absolute_dllfile_path)
+        else:
+            ctp = CDLL('WinDataCollect.dll')
+            if self.__isX64():
+                func_name = '?CTP_GetSystemInfo@@YAHPEADAEAH@Z'
+            else:
+                func_name = '?CTP_GetSystemInfo@@YAHPADAAH@Z'
+        result = ctp[func_name](array, len)
         temp_list = array[:len[0]]
         info = ','.join(list(map(str, temp_list)))
         return result, info
@@ -106,10 +122,15 @@ class SupervisionHelper:
         supInfo.ExceptionType = str(except_code)
         return json
 
+    def __isX64(self):
+        return sys.maxsize > 2**32
+
+    def __isLinux(self):
+        return sys.platform == "linux" or sys.platform == "linux2"
+
 if __name__ == '__main__':
     #Supervision文件夹放到此文件目录下
-    dir = os.path.join(os.path.dirname(__file__), 'Supervision')
-    helper = SupervisionHelper(dir)
+    helper = SupervisionHelper()
     
     #dingdian
     print('dingdian')
