@@ -101,7 +101,7 @@ class WebSocketClient(object):
                  self.__lastActiveTime = datetime.datetime.now()
                  self.__unhandledQueue.put(msg)
             except Exception as e:
-                logger.error(self.config.address + 'receive msg exception',e)
+                logger.exception(e)
                 time.sleep(1)
 
     def __HandleMsg(self):
@@ -114,7 +114,7 @@ class WebSocketClient(object):
                     continue
                 self.__RaiseMessage(msg)
             except Exception as e:
-                logger.error(self.config.address + 'handle msg exception',e)
+                logger.exception(e)
                 time.sleep(1)
     
     def __AutoHeartBeat(self):
@@ -135,7 +135,7 @@ class WebSocketClient(object):
                 self.Send(self.config.hbContent)
                 logger.debug("send heart beat:{0}".format(self.config.address))
             except Exception as e:
-                logger.error(self.config.address + 'heart beat exception',e)
+                logger.exception(e)
                 self.__Close()
 
     def __RaiseMessage(self,msg):
@@ -151,7 +151,7 @@ class WebSocketClient(object):
                 self.__wsclinet.close()
             self.__wsclinet = None
         except Exception as e:
-            logger.error(self.config.address +'close connect excetpion',e)
+            logger.exception(e)
         
         
 if __name__ == '__main__':
